.. Copyright (C) 2015 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Troubleshooting
===============

You can increase the log verbosity by making ``stunnel_debug`` variable higher,
for example ``'6'`` or ``'7'``.

